netapp_ontap.models.cluster_peer_local_network API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_peer_local_network`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterPeerLocalNetworkSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterPeerLocalNetwork object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `broadcast_domain: str GET POST PATCH`

    Broadcast domain that is in use within the IPspace.

    Example: bd1

  `gateway: str GET POST PATCH`

    The IPv4 or IPv6 address of the default router.

    Example: 10.1.1.1

  `interfaces: List[ClusterPeerLocalNetworkInterfaces] GET POST PATCH`

    The interfaces field of the cluster_peer_local_network.

  `netmask: str GET POST PATCH`

    IPv4 mask or netmask length.

    Example: 255.255.0.0